@@ -1,4 +1,4 @@
-use aliri_braid::braid;
+use crate::api::AnyFilesUrl;
 use async_stream::stream;
 use futures::Stream;
 use serde::{de::DeserializeOwned, Deserialize, Serialize};
@@ -43,33 +43,4 @@ pub(crate) struct Paginated<U, T> {
     pub results: Vec<T>,
 }
 
-/// A URL which produces a collection of files.
-///
-/// # Examples
-///
-/// - https://cube.chrisproject.org/api/v1/files/
-/// - https://cube.chrisproject.org/api/v1/files/search/
-/// - https://cube.chrisproject.org/api/v1/uploadedfiles/search/?fname=txt
-/// - https://cube.chrisproject.org/api/v1/20/files/
-/// - https://cube.chrisproject.org/api/v1/plugins/instances/40/files/
-#[braid(serde)]
-pub struct AnyFilesUrl;
 impl PaginatedUrl for AnyFilesUrl {}
-
-/// Download URL for a file resource.
-///
-/// # Examples
-///
-/// - https://cube.chrisproject.org/api/v1/files/84360/aparc.a2009s+aseg.mgz
-#[braid(serde)]
-pub struct FileResourceUrl;
-
-/// File fname.
-#[braid(serde)]
-pub struct FileResourceFname;
-
-#[derive(Deserialize)]
-pub struct DownloadableFile {
-    pub file_resource: FileResourceUrl,
-    pub fname: FileResourceFname,
-}
